---
hide:
    - toc
---
# 🇩🇰 Danish

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-jBKLq" src="https://datawrapper.dwcdn.net/jBKLq" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="833" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}(); </script>
///

/// tab | NLU Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-V6Ga5" src="https://datawrapper.dwcdn.net/V6Ga5" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="833" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | Generative Scatter Plot
<iframe title="Performance of Generative Language Models on Danish Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-bqdNW" src="https://datawrapper.dwcdn.net/bqdNW/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="668" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Performance of Language Models on Danish NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-sBTCs" src="https://datawrapper.dwcdn.net/sBTCs/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///
